@@ -50,7 +50,7 @@ import pyflakes.messages
 import pyflakes.reporter
 
 
-__version__ = "2.2.1"
+__version__ = "2.3.0"
 
 
 _LOGGER = logging.getLogger("autoflake")
@@ -63,6 +63,11 @@ PYTHON_SHEBANG_REGEX = re.compile(r"^#!.*\bpython[3]?\b\s*$")
 
 MAX_PYTHON_FILE_DETECTION_BYTES = 1024
 
+IGNORE_COMMENT_REGEX = re.compile(
+    r"\s*#\s{1,}autoflake:\s{1,}\bskip_file\b",
+    re.MULTILINE,
+)
+
 
 def standard_paths() -> Iterable[str]:
     """Yield paths to standard modules."""
@@ -570,8 +575,7 @@ def filter_code(
     undefined_names: list[str] = []
     if expand_star_imports and not (
         # See explanations in #18.
-        re.search(r"\b__all__\b", source)
-        or re.search(r"\bdel\b", source)
+        re.search(r"\b__all__\b", source) or re.search(r"\bdel\b", source)
     ):
         marked_star_import_line_numbers = frozenset(
             star_import_used_line_numbers(messages),
@@ -905,6 +909,9 @@ def fix_code(
     if not source:
         return source
 
+    if IGNORE_COMMENT_REGEX.search(source):
+        return source
+
     # pyflakes does not handle "nonlocal" correctly.
     if "nonlocal" in source:
         remove_unused_variables = False
@@ -1252,7 +1259,11 @@ def merge_configuration_file(
 
     if "config_file" in flag_args:
         config_file = pathlib.Path(flag_args["config_file"]).resolve()
-        config = process_config_file(str(config_file))
+        process_method = process_config_file
+        if config_file.suffix == ".toml":
+            process_method = process_pyproject_toml
+
+        config = process_method(str(config_file))
 
         if not config:
             _LOGGER.error(
@@ -1503,8 +1514,9 @@ def _main(
     if not success:
         return 1
 
-    if args["remove_rhs_for_unused_variables"] and not (
-        args["remove_unused_variables"]
+    if (
+        args["remove_rhs_for_unused_variables"]
+        and not (args["remove_unused_variables"])
     ):
         _LOGGER.error(
             "Using --remove-rhs-for-unused-variables only makes sense when "
