@@ -928,6 +928,7 @@ StrictVersion('1.0.0')
 from distutils.version import LooseVersion, StrictVersion
 StrictVersion('1.0.0')
 """,
+                remove_all_unused_imports=True,
             ),
         )
 
@@ -941,6 +942,7 @@ version('1.0.0')
 from distutils.version import LooseVersion, StrictVersion as version
 version('1.0.0')
 """,
+                remove_all_unused_imports=True,
             ),
         )
 
@@ -2006,6 +2008,49 @@ class SystemTests(unittest.TestCase):
 
     """System tests."""
 
+    def test_skip_file(self) -> None:
+        skipped_file_file_text = """
+# autoflake: skip_file
+import re
+import os
+import my_own_module
+x = 1
+"""
+        with temporary_file(skipped_file_file_text) as filename:
+            output_file = io.StringIO()
+            autoflake._main(
+                argv=["my_fake_program", filename, "--stdout"],
+                standard_out=output_file,
+                standard_error=None,
+            )
+            self.assertEqual(
+                skipped_file_file_text,
+                output_file.getvalue(),
+            )
+
+    def test_skip_file_with_shebang_respect(self) -> None:
+        skipped_file_file_text = """
+#!/usr/bin/env python3
+
+# autoflake: skip_file
+
+import re
+import os
+import my_own_module
+x = 1
+"""
+        with temporary_file(skipped_file_file_text) as filename:
+            output_file = io.StringIO()
+            autoflake._main(
+                argv=["my_fake_program", filename, "--stdout"],
+                standard_out=output_file,
+                standard_error=None,
+            )
+            self.assertEqual(
+                skipped_file_file_text,
+                output_file.getvalue(),
+            )
+
     def test_diff(self) -> None:
         with temporary_file(
             """\
@@ -3387,6 +3432,28 @@ class ConfigFileTest(unittest.TestCase):
                 check=True,
             )
 
+    def test_merge_configuration_file__toml_config_option(self) -> None:
+        with temporary_file(
+            suffix=".toml",
+            contents=("[tool.autoflake]\n" "check = true\n"),
+        ) as temp_config:
+            self.create_file("test_me.py")
+            files = [self.effective_path("test_me.py")]
+
+            args, success = autoflake.merge_configuration_file(
+                {
+                    "files": files,
+                    "config_file": temp_config,
+                },
+            )
+
+            assert success is True
+            assert args == self.with_defaults(
+                files=files,
+                config_file=temp_config,
+                check=True,
+            )
+
     def test_load_false(self) -> None:
         self.create_file("test_me.py")
         self.create_file(
